## Preparing user guidance and documentation

As mentioned earlier, performing a physics analyses with the open data from the LHC is far from trivial. To lower the barrier of entry and make the datasets meaningful for students, citizen scientists and members of the wider particle-physics community, clear and thorough documentation has been provided, either on the Portal itself or via external resources stored on CERN webpages.

Performing a high-level analysis on the datasets requires the use of a special software framework, known as ROOT\footnote{\url{https://root.cern.ch/about-root}}, which was developed at CERN. In addition to ROOT, detector-specific software packages are needed to analyse data from the different LHC collaborations. For example, CMS uses a framework called CMSSW\footnote{\url{https://cms-sw.github.io/}}. To streamline access to these tools, the software environments necessary to perform a physics analysis on the LHC datasets are captured using the CernVM\footnote{\url{http://cernvm.cern.ch/}} technology. The CernVM Virtual Software Appliance provides a complete, portable and easy-to-configure user environment for developing and running LHC data analysis locally or on institutional and commercial clouds (such as OpenStack, Amazon EC2, Google Compute Engine). Use of CernVM removes the need for separately installing the various software packages and libraries. Documentation on the Portal also guides the users through the basic actions needed to familiarise themselves with the tools provided.

Once the datasets, the software environments and the documentation have been
assembled, an important challenge was to present this information in an
easy-to-use way. A considerable effort was therefore devoted to an attractive presentation of assembled data and tools needed to work with them.

Further, precise instructions were provided for getting started with an analysis using the CMS data, by documenting the installation and testing of the applicable virtual machines and the initialisation of the CMS analysis environment. Prior to the release of the data, these steps were extensively tested on a variety of hardware and software configurations. A validation report, based on this testing, was also produced and made available on the Portal.

Yet another barrier -- one that might not seem obvious to those used to working with particle-physics datasets -- is one of vocabulary. This isn't limited just to the terminologies within particle physics -- several terms are used in CMS-specific contexts, referring to the analysis software or to the information recorded in the datasets themselves. A Portal-wide glossary\footnote{\url{http://opendata.cern.ch/glossary}} was therefore created; terms included in the glossary are highlighted on all pages on the Portal, and hovering on the term displays the definition. This helps provide contextual information within the documentation.
